==> bitbucket-server-cli-0.1.0.tgz: package/src/plugins/permissions/Validator.js <==
'use strict';

const chalk = require('chalk');
const PermissionError = require('./PermissionError');

class Validator {
  constructor(bitbucket) {
    this.bitbucket = bitbucket;
    this.errors = [];
  }

  validateProject(project) {
    let projectPromises = [];

    projectPromises.push(this.validateProjectGroupPermissions(project));
    projectPromises.push(this.validateProjectUserPermissions(project));
    projectPromises.push(this.processProjectRepos(project));

    return Promise.all(projectPromises);
  }

  processProjectRepos(project) {
    // Fetch Repo Info Below
    return new Promise((resolve, reject) => {
      this.bitbucket.retrieveRepositories(project.key).then((repos) => {
        this.validateProjectRepos(project, repos).then(function() {
          console.log(chalk.green(chalk.bold(project.key) + ' project audit complete'));
          resolve();
        });
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateProjectGroupPermissions(project) {
    return new Promise((resolve, reject) => {
      this.bitbucket.retrieveProjectGroupPermissions(project.key).then((groups) => {
        this.errors = this.errors.concat(this.auditPermissions(project, '', groups, 'Group', project.projectPermissions.groups));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateProjectUserPermissions(project) {
    return new Promise((resolve, reject) => {
      this.bitbucket.retrieveProjectUserPermissions(project.key).then((users) => {
        this.errors = this.errors.concat(this.auditPermissions(project, '', users, 'Users', project.projectPermissions.users));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateProjectRepos(project, repos) {
    let repoPromises = [];

    repos.forEach((repo) => {
      repoPromises.push(this.validateRepo(project, repo));
    });

    return Promise.all(repoPromises);
  }

  validateRepo(project, repo) {
    let repoPromises = [];

    repoPromises.push(this.validateRepoUserPermissions(project, repo));
    repoPromises.push(this.validateRepoGroupPermissions(project, repo));

    return Promise.all(repoPromises);
  }

  validateRepoGroupPermissions(project, repo) {
    return new Promise((resolve, reject) => {
      this.bitbucket.retrieveRepoGroupPermissions(repo.project.key, repo.slug).then((groups) => {
        this.errors = this.errors.concat(this.auditPermissions(project, repo, groups, 'Group', project.repoPermissions.groups));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateRepoUserPermissions(project, repo) {
    return new Promise((resolve, reject) => {
      this.bitbucket.retrieveRepoUserPermissions(repo.project.key, repo.slug).then((users) => {
        this.errors = this.errors.concat(this.auditPermissions(project, repo, users, 'Users', project.repoPermissions.users));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  auditPermissions(project, repo, array, entityType, validPermissions) {
    let repoName = repo.hasOwnProperty('slug') ? repo.slug : '';
    let errors = [];

    for (let arrayValue of array) {
      let isValidEntity = validPermissions.hasOwnProperty(this.getName(arrayValue, entityType));
      let isValidPermission = validPermissions[this.getName(arrayValue, entityType)] === this.getPermissionName(arrayValue);
      if(!isValidEntity || !isValidPermission) {
        let permissionError = new PermissionError(project.key, repoName, entityType, this.getDisplayName(arrayValue, entityType), this.getPermissionName(arrayValue));
        errors.push(permissionError);
      }
    }

    return errors;
  }

  getName(arrayItem, entityType) {
    if (entityType === 'Users') {
      return arrayItem.user.name;
    }

    return arrayItem.group.name;
  }

  getDisplayName(arrayItem, entityType) {
    if (entityType === 'Users') {
      return arrayItem.user.displayName;
    }

    return arrayItem.group.name;
  }

  getPermissionName(arrayItem) {
    return arrayItem.permission;
  }

  getErrors() {
    return this.errors;
  }
}

module.exports = Validator;

==> bitbucket-server-cli-0.2.0.tgz: package/src/plugins/permissions/Validator.js <==
'use strict';

const chalk = require('chalk');
const PermissionError = require('./PermissionError');

class Validator {

  /**
   * Creates an instance of Validator.
   * @param {Object} bitbucketApiClient BitbucketApiClient object
   * @memberof Validator
   */
  constructor(bitbucketApiClient) {
    this.bitbucketApiClient = bitbucketApiClient;
    this.errors = [];
  }

  validateProject(project) {
    let projectPromises = [];

    projectPromises.push(this.validateProjectGroupPermissions(project));
    projectPromises.push(this.validateProjectUserPermissions(project));
    projectPromises.push(this.processProjectRepos(project));

    return Promise.all(projectPromises);
  }

  processProjectRepos(project) {
    // Fetch Repo Info Below
    return new Promise((resolve, reject) => {
      this.bitbucketApiClient.getRepos(project.key).then((repos) => {
        this.validateProjectRepos(project, repos).then(function() {
          console.log(chalk.green(chalk.bold(project.key) + ' project audit complete'));
          resolve();
        });
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateProjectGroupPermissions(project) {
    return new Promise((resolve, reject) => {
      this.bitbucketApiClient.getProjectGroupPermissions(project.key).then((groups) => {
        this.errors = this.errors.concat(this.auditPermissions(project, '', groups, 'Group', project.projectPermissions.groups));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateProjectUserPermissions(project) {
    return new Promise((resolve, reject) => {
      this.bitbucketApiClient.getProjectUserPermissions(project.key).then((users) => {
        this.errors = this.errors.concat(this.auditPermissions(project, '', users, 'Users', project.projectPermissions.users));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateProjectRepos(project, repos) {
    let repoPromises = [];

    repos.forEach((repo) => {
      repoPromises.push(this.validateRepo(project, repo));
    });

    return Promise.all(repoPromises);
  }

  validateRepo(project, repo) {
    let repoPromises = [];

    repoPromises.push(this.validateRepoUserPermissions(project, repo));
    repoPromises.push(this.validateRepoGroupPermissions(project, repo));

    return Promise.all(repoPromises);
  }

  validateRepoGroupPermissions(project, repo) {
    return new Promise((resolve, reject) => {
      this.bitbucketApiClient.getRepoGroupPermissions(repo.project.key, repo.slug).then((groups) => {
        this.errors = this.errors.concat(this.auditPermissions(project, repo, groups, 'Group', project.repoPermissions.groups));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  validateRepoUserPermissions(project, repo) {
    return new Promise((resolve, reject) => {
      this.bitbucketApiClient.getRepoUserPermissions(repo.project.key, repo.slug).then((users) => {
        this.errors = this.errors.concat(this.auditPermissions(project, repo, users, 'Users', project.repoPermissions.users));
        resolve();
      }).catch(function(error) {
        reject(error);
      });
    });
  }

  auditPermissions(project, repo, array, entityType, validPermissions) {
    let repoName = repo.hasOwnProperty('slug') ? repo.slug : '';
    let errors = [];

    for (let arrayValue of array) {
      let isValidEntity = validPermissions.hasOwnProperty(this.getName(arrayValue, entityType));
      let isValidPermission = validPermissions[this.getName(arrayValue, entityType)] === this.getPermissionName(arrayValue);
      if(!isValidEntity || !isValidPermission) {
        let permissionError = new PermissionError(project.key, repoName, entityType, this.getDisplayName(arrayValue, entityType), this.getPermissionName(arrayValue));
        errors.push(permissionError);
      }
    }

    return errors;
  }

  getName(arrayItem, entityType) {
    if (entityType === 'Users') {
      return arrayItem.user.name;
    }

    return arrayItem.group.name;
  }

  getDisplayName(arrayItem, entityType) {
    if (entityType === 'Users') {
      return arrayItem.user.displayName;
    }

    return arrayItem.group.name;
  }

  getPermissionName(arrayItem) {
    return arrayItem.permission;
  }

  getErrors() {
    return this.errors;
  }
}

module.exports = Validator;
